You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/12 08:15:24 UTC

[46/64] [abbrv] [partial] incubator-ignite git commit: Rename GridException to IgniteCheckedException, GridRuntimeException to IgniteException.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java
index 654ec14..6deb188 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java
@@ -72,7 +72,7 @@ public class GridifyDefaultTask extends ComputeTaskAdapter<GridifyArgument, Obje
     }
 
     /** {@inheritDoc} */
-    @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, GridifyArgument arg) throws GridException {
+    @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, GridifyArgument arg) throws IgniteCheckedException {
         assert !subgrid.isEmpty() : "Subgrid should not be empty: " + subgrid;
 
         assert ignite != null : "Grid instance could not be injected";
@@ -91,7 +91,7 @@ public class GridifyDefaultTask extends ComputeTaskAdapter<GridifyArgument, Obje
     }
 
     /** {@inheritDoc} */
-    @Override public final Object reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public final Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         assert results.size() == 1;
 
         ComputeJobResult res = results.get(0);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToSetAbstractAspect.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java
index d791197..0164d86 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java
@@ -9,13 +9,13 @@
 
 package org.apache.ignite.fs;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 /**
  * {@code GGFS} exception thrown by file system components.
  */
-public class IgniteFsException extends GridException {
+public class IgniteFsException extends IgniteCheckedException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java
index 0d35621..cb0257a 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java
@@ -71,7 +71,7 @@ public class IgniteFsByteDelimiterRecordResolver implements IgniteFsRecordResolv
 
     /** {@inheritDoc} */
     @Override public IgniteFsFileRange resolveRecords(IgniteFs ggfs, IgniteFsInputStream stream,
-        IgniteFsFileRange suggestedRecord) throws GridException, IOException {
+        IgniteFsFileRange suggestedRecord) throws IgniteCheckedException, IOException {
         long suggestedStart = suggestedRecord.start();
         long suggestedEnd = suggestedStart + suggestedRecord.length();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java
index 70091cf..a1639d0 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java
@@ -47,7 +47,7 @@ public class IgniteFsFixedLengthRecordResolver implements IgniteFsRecordResolver
     /** {@inheritDoc} */
     @Override public IgniteFsFileRange resolveRecords(IgniteFs ggfs, IgniteFsInputStream stream,
         IgniteFsFileRange suggestedRecord)
-        throws GridException, IOException {
+        throws IgniteCheckedException, IOException {
         long suggestedEnd = suggestedRecord.start() + suggestedRecord.length();
 
         long startRem = suggestedRecord.start() % recLen;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java
index 5333b47..692c725 100644
--- a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java
+++ b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java
@@ -9,13 +9,13 @@
 
 package org.apache.ignite.lang;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 /**
  * Future computation cannot be retrieved because it was cancelled.
  */
-public class IgniteFutureCancelledException extends GridException {
+public class IgniteFutureCancelledException extends IgniteCheckedException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java
index 2a3437a..68d3d53 100644
--- a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java
+++ b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java
@@ -9,13 +9,13 @@
 
 package org.apache.ignite.lang;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 /**
  * Future computation completion is timed out.
  */
-public class IgniteFutureTimeoutException extends GridException {
+public class IgniteFutureTimeoutException extends IgniteCheckedException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLogger.java b/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLogger.java
index 8f28634..9e806fd 100644
--- a/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLogger.java
+++ b/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLogger.java
@@ -348,7 +348,7 @@ public class IgniteJavaLogger extends GridMetadataAwareAdapter implements Ignite
         try {
             fileHnd.nodeId(nodeId);
         }
-        catch (GridException | IOException e) {
+        catch (IgniteCheckedException | IOException e) {
             throw new RuntimeException("Failed to enable file handler.", e);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLoggerFileHandler.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLoggerFileHandler.java b/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLoggerFileHandler.java
index 80d56f3..4afd111 100644
--- a/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLoggerFileHandler.java
+++ b/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLoggerFileHandler.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.logger.java;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
@@ -68,7 +68,7 @@ public final class IgniteJavaLoggerFileHandler extends StreamHandler {
      *
      * @param nodeId Node id.
      */
-    public void nodeId(UUID nodeId) throws GridException, IOException {
+    public void nodeId(UUID nodeId) throws IgniteCheckedException, IOException {
         if (delegate != null)
             return;
 
@@ -123,7 +123,7 @@ public final class IgniteJavaLoggerFileHandler extends StreamHandler {
      *
      * @return Logging directory.
      */
-    private static File logDirectory() throws GridException {
+    private static File logDirectory() throws IgniteCheckedException {
         return !F.isEmpty(U.GRIDGAIN_LOG_DIR) ? new File(U.GRIDGAIN_LOG_DIR) : U.resolveWorkDirectory("log", false);
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java
index 5002e63..7a5e91f 100644
--- a/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java
+++ b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java
@@ -9,10 +9,10 @@
 
 package org.apache.ignite.marshaller;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.io.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
 /**
@@ -26,7 +26,7 @@ public abstract class IgniteAbstractMarshaller implements IgniteMarshaller {
     public static final int DFLT_BUFFER_SIZE = 512;
 
     /** {@inheritDoc} */
-    @Override public byte[] marshal(@Nullable Object obj) throws GridException {
+    @Override public byte[] marshal(@Nullable Object obj) throws IgniteCheckedException {
         GridByteArrayOutputStream out = null;
 
         try {
@@ -42,7 +42,7 @@ public abstract class IgniteAbstractMarshaller implements IgniteMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) throws GridException {
+    @Override public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) throws IgniteCheckedException {
         GridByteArrayInputStream in = null;
 
         try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java b/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java
index 97e5f4a..1853ee7 100644
--- a/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java
+++ b/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java
@@ -9,8 +9,8 @@
 
 package org.apache.ignite.marshaller.jdk;
 
+import org.apache.ignite.*;
 import org.apache.ignite.marshaller.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
@@ -78,7 +78,7 @@ import java.io.*;
  */
 public class IgniteJdkMarshaller extends IgniteAbstractMarshaller {
     /** {@inheritDoc} */
-    @Override public void marshal(@Nullable Object obj, OutputStream out) throws GridException {
+    @Override public void marshal(@Nullable Object obj, OutputStream out) throws IgniteCheckedException {
         assert out != null;
 
         ObjectOutputStream objOut = null;
@@ -92,7 +92,7 @@ public class IgniteJdkMarshaller extends IgniteAbstractMarshaller {
             objOut.flush();
         }
         catch (IOException e) {
-            throw new GridException("Failed to serialize object: " + obj, e);
+            throw new IgniteCheckedException("Failed to serialize object: " + obj, e);
         }
         finally{
             U.closeQuiet(objOut);
@@ -101,7 +101,7 @@ public class IgniteJdkMarshaller extends IgniteAbstractMarshaller {
 
     /** {@inheritDoc} */
     @SuppressWarnings({"unchecked"})
-    @Override public <T> T unmarshal(InputStream in, @Nullable ClassLoader clsLdr) throws GridException {
+    @Override public <T> T unmarshal(InputStream in, @Nullable ClassLoader clsLdr) throws IgniteCheckedException {
         assert in != null;
 
         if (clsLdr == null)
@@ -115,10 +115,10 @@ public class IgniteJdkMarshaller extends IgniteAbstractMarshaller {
             return (T)objIn.readObject();
         }
         catch (IOException e) {
-            throw new GridException("Failed to deserialize object with given class loader: " + clsLdr, e);
+            throw new IgniteCheckedException("Failed to deserialize object with given class loader: " + clsLdr, e);
         }
         catch (ClassNotFoundException e) {
-            throw new GridException("Failed to find class with given class loader for unmarshalling " +
+            throw new IgniteCheckedException("Failed to find class with given class loader for unmarshalling " +
                 "(make sure same versions of all classes are available on all nodes or enable peer-class-loading): " +
                 clsLdr, e);
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedObjectStreamRegistry.java b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedObjectStreamRegistry.java
index f4e8c8c..28cbcad 100644
--- a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedObjectStreamRegistry.java
+++ b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedObjectStreamRegistry.java
@@ -9,6 +9,7 @@
 
 package org.apache.ignite.marshaller.optimized;
 
+import org.apache.ignite.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.io.*;
@@ -194,7 +195,7 @@ class IgniteOptimizedObjectStreamRegistry {
                 return new IgniteOptimizedObjectOutputStream(new GridUnsafeDataOutput(4 * 1024));
             }
             catch (IOException e) {
-                throw new GridRuntimeException("Failed to create object output stream.", e);
+                throw new IgniteException("Failed to create object output stream.", e);
             }
         }
 
@@ -208,7 +209,7 @@ class IgniteOptimizedObjectStreamRegistry {
                 return new IgniteOptimizedObjectInputStream(new GridUnsafeDataInput());
             }
             catch (IOException e) {
-                throw new GridRuntimeException("Failed to create object input stream.", e);
+                throw new IgniteException("Failed to create object input stream.", e);
             }
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.previous.properties
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.previous.properties b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.previous.properties
index 117b1b9..1b1f1e8 100644
--- a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.previous.properties
+++ b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.previous.properties
@@ -4610,7 +4610,7 @@ org.gridgain.grid.GridJobWrapper
 org.gridgain.grid.GridLicenseException
 org.gridgain.grid.GridLifecycleEventType
 org.gridgain.grid.GridMultiException
-org.gridgain.grid.GridRuntimeException
+org.gridgain.grid.IgniteException
 org.gridgain.grid.GridSpringBean
 org.gridgain.grid.GridTaskCancelledException
 org.gridgain.grid.GridTaskSessionScope

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.properties
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.properties b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.properties
index 117b1b9..1b1f1e8 100644
--- a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.properties
+++ b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/optimized-classnames.properties
@@ -4610,7 +4610,7 @@ org.gridgain.grid.GridJobWrapper
 org.gridgain.grid.GridLicenseException
 org.gridgain.grid.GridLifecycleEventType
 org.gridgain.grid.GridMultiException
-org.gridgain.grid.GridRuntimeException
+org.gridgain.grid.IgniteException
 org.gridgain.grid.GridSpringBean
 org.gridgain.grid.GridTaskCancelledException
 org.gridgain.grid.GridTaskSessionScope

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java
index bff63e9..eba4cae 100644
--- a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java
+++ b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.plugin.security;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 import java.util.*;
 
@@ -77,7 +77,7 @@ public interface GridSecurity {
      *
      * @return Collection of authenticated subjects.
      */
-    public Collection<GridSecuritySubject> authenticatedSubjects() throws GridException;
+    public Collection<GridSecuritySubject> authenticatedSubjects() throws IgniteCheckedException;
 
     /**
      * Gets security subject based on subject ID.
@@ -85,5 +85,5 @@ public interface GridSecurity {
      * @param subjId Subject ID.
      * @return Authorized security subject.
      */
-    public GridSecuritySubject authenticatedSubject(UUID subjId) throws GridException;
+    public GridSecuritySubject authenticatedSubject(UUID subjId) throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java
index 1cc184b..0cabf26 100644
--- a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java
+++ b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.plugin.security;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 /**
  * Basic implementation for {@link GridSecurityCredentialsProvider}. Use it
@@ -30,7 +30,7 @@ public class GridSecurityCredentialsBasicProvider implements GridSecurityCredent
     }
 
     /** {@inheritDoc} */
-    @Override public GridSecurityCredentials credentials() throws GridException {
+    @Override public GridSecurityCredentials credentials() throws IgniteCheckedException {
         return cred;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityException.java b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityException.java
index b8899df..cea2085 100644
--- a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityException.java
+++ b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityException.java
@@ -9,13 +9,13 @@
 
 package org.apache.ignite.plugin.security;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 /**
  * Common security exception for the grid.
  */
-public class GridSecurityException extends GridRuntimeException {
+public class GridSecurityException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/portables/PortableException.java b/modules/core/src/main/java/org/apache/ignite/portables/PortableException.java
index a6815c0..b8289e5 100644
--- a/modules/core/src/main/java/org/apache/ignite/portables/PortableException.java
+++ b/modules/core/src/main/java/org/apache/ignite/portables/PortableException.java
@@ -9,13 +9,13 @@
 
 package org.apache.ignite.portables;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 /**
  * Exception indicating portable object serialization error.
  */
-public class PortableException extends GridRuntimeException {
+public class PortableException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java
index 4ce3edf..de09649 100644
--- a/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java
+++ b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java
@@ -9,14 +9,14 @@
 
 package org.apache.ignite.product;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
 /**
  * This exception is thrown when license violation is detected.
  */
-public class IgniteProductLicenseException extends GridException {
+public class IgniteProductLicenseException extends IgniteCheckedException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java
index 15720f2..540b3e9 100644
--- a/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java
+++ b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.product;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
@@ -273,7 +273,7 @@ public class IgniteProductVersion implements Comparable<IgniteProductVersion>, E
 
                 return new IgniteProductVersion(major, minor, maintenance, stage, revTs, revHash);
             }
-            catch (IllegalStateException | IndexOutOfBoundsException | NumberFormatException | GridException e) {
+            catch (IllegalStateException | IndexOutOfBoundsException | NumberFormatException | IgniteCheckedException e) {
                 throw new IllegalStateException("Failed to parse version: " + verStr, e);
             }
         }
diff --git a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToSetAbstractAspect.java b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToSetAbstractAspect.java
index 8f55157..a971614 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToSetAbstractAspect.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToSetAbstractAspect.java
@@ -30,9 +30,9 @@ public class GridifySetToSetAbstractAspect {
      * Check method signature.
      *
      * @param mtd Grid-enabled method.
      * @throws GridException If method signature invalid..
      */
-    protected void checkMethodSignature(Method mtd) throws GridException {
+    protected void checkMethodSignature(Method mtd) throws IgniteCheckedException {
         Class<?>[] paramTypes = mtd.getParameterTypes();
 
         Collection<Integer> allowedParamIdxs = new LinkedList<>();
@@ -45,7 +45,7 @@ public class GridifySetToSetAbstractAspect {
         }
 
         if (allowedParamIdxs.isEmpty()) {
-            throw new GridException("Invalid method signature. Failed to get valid method parameter types " +
+            throw new IgniteCheckedException("Invalid method signature. Failed to get valid method parameter types " +
                 "[mtdName=" + mtd.getName() + ", allowedTypes=" + GridifyUtils.getAllowedMethodParameterTypes() + ']');
         }
 
@@ -59,27 +59,27 @@ public class GridifySetToSetAbstractAspect {
         }
 
         if (annParamIdxs.size() > 1) {
-            throw new GridException("Invalid method signature. Only one method parameter can may annotated with @" +
+            throw new IgniteCheckedException("Invalid method signature. Only one method parameter can may annotated with @" +
                 GridifyInput.class.getSimpleName() +
                 "[mtdName=" + mtd.getName() + ", allowedTypes=" + GridifyUtils.getAllowedMethodParameterTypes() +
                 ", annParamIdxs=" + annParamIdxs + ']');
         }
 
         if (allowedParamIdxs.size() > 1 && annParamIdxs.isEmpty()) {
-            throw new GridException("Invalid method signature. Method parameter must be annotated with @" +
+            throw new IgniteCheckedException("Invalid method signature. Method parameter must be annotated with @" +
                 GridifyInput.class.getSimpleName() +
                 "[mtdName=" + mtd.getName() + ", allowedTypes=" + GridifyUtils.getAllowedMethodParameterTypes() +
                 ", allowedParamIdxs=" + allowedParamIdxs + ']');
         }
 
         if (!annParamIdxs.isEmpty() && !allowedParamIdxs.contains(annParamIdxs.get(0))) {
-            throw new GridException("Invalid method signature. Invalid annotated parameter " +
+            throw new IgniteCheckedException("Invalid method signature. Invalid annotated parameter " +
                 "[mtdName=" + mtd.getName() + ", allowedTypes=" + GridifyUtils.getAllowedMethodParameterTypes() +
                 ", allowedParamIdxs=" + allowedParamIdxs + ", annParamIdxs=" + annParamIdxs + ']');
         }
 
         if (!GridifyUtils.isMethodReturnTypeValid(mtd.getReturnType())) {
-            throw new GridException("Invalid method signature. Invalid method return type " +
+            throw new IgniteCheckedException("Invalid method signature. Invalid method return type " +
                 "[mtdName=" + mtd.getName() + ", allowedTypes=" + GridifyUtils.getAllowedMethodReturnTypes() +
                 ", mtdReturnType=" + mtd.getReturnType() + ']');
         }
@@ -93,11 +93,11 @@ public class GridifySetToSetAbstractAspect {
      *
      * @param arg Gridify argument.
      * @param ann Annotation
      * @throws GridException If split is not allowed with current parameters.
      */
-    protected void checkIsSplitToJobsAllowed(GridifyRangeArgument arg, GridifySetToSet ann) throws GridException {
+    protected void checkIsSplitToJobsAllowed(GridifyRangeArgument arg, GridifySetToSet ann) throws IgniteCheckedException {
         if (arg.getInputSize() == UNKNOWN_SIZE && ann.threshold() <= 0 && ann.splitSize() <= 0) {
-            throw new GridException("Failed to split input method argument to jobs with unknown input size and " +
+            throw new IgniteCheckedException("Failed to split input method argument to jobs with unknown input size and " +
                 "invalid annotation parameter 'splitSize' [mtdName=" + arg.getMethodName() + ", inputTypeCls=" +
                 arg.getMethodParameterTypes()[arg.getParamIndex()].getName() +
                 ", threshold=" + ann.threshold() + ", splitSize=" + ann.splitSize() + ']');
@@ -116,10 +116,10 @@ public class GridifySetToSetAbstractAspect {
      * @param splitSize Size of elements to send in job argument.
      * @param timeout Execution timeout.
      * @return Result.
      * @throws GridException If execution failed.
      */
     protected Object execute(IgniteCompute compute, Class<?> cls, GridifyRangeArgument arg,
-        GridifyNodeFilter nodeFilter, int threshold, int splitSize, long timeout) throws GridException {
+        GridifyNodeFilter nodeFilter, int threshold, int splitSize, long timeout) throws IgniteCheckedException {
         long now = U.currentTimeMillis();
 
         long end = timeout == 0 ? Long.MAX_VALUE : timeout + now;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToValueAbstractAspect.java
----------------------------------------------------------------------
@@ -30,9 +30,9 @@ public class GridifySetToSetAbstractAspect {
      *
      * @param mtd Grid-enabled method.
-     * @throws GridException If method signature invalid..
+     * @throws IgniteCheckedException If method signature invalid..
      */
@@ -93,11 +93,11 @@ public class GridifySetToSetAbstractAspect {
      * @param arg Gridify argument.
      * @param ann Annotation
-     * @throws GridException If split is not allowed with current parameters.
+     * @throws IgniteCheckedException If split is not allowed with current parameters.
      */
@@ -116,10 +116,10 @@ public class GridifySetToSetAbstractAspect {
      * @param timeout Execution timeout.
      * @return Result.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
     protected Object execute(IgniteCompute compute, Class<?> cls, GridifyRangeArgument arg,
diff --git a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToValueAbstractAspect.java b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToValueAbstractAspect.java
index 8185270..7802c55 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToValueAbstractAspect.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifySetToValueAbstractAspect.java
@@ -30,9 +30,9 @@ public class GridifySetToValueAbstractAspect {
      * Check method signature.
      *
      * @param mtd Grid-enabled method.
      * @throws GridException If method signature invalid.
      */
-    protected void checkMethodSignature(Method mtd) throws GridException {
+    protected void checkMethodSignature(Method mtd) throws IgniteCheckedException {
         Class<?>[] paramTypes = mtd.getParameterTypes();
 
         Collection<Integer> allowedParamIdxs = new LinkedList<>();
@@ -45,7 +45,7 @@ public class GridifySetToValueAbstractAspect {
         }
 
         if (allowedParamIdxs.isEmpty()) {
-            throw new GridException("Invalid method signature. Failed to get valid method parameter types " +
+            throw new IgniteCheckedException("Invalid method signature. Failed to get valid method parameter types " +
                 "[mtdName=" + mtd.getName() + ", allowedTypes=" + GridifyUtils.getAllowedMethodParameterTypes() + ']');
         }
 
@@ -59,21 +59,21 @@ public class GridifySetToValueAbstractAspect {
         }
 
         if (annParamIdxs.size() > 1) {
-            throw new GridException("Invalid method signature. Only one method parameter can may annotated with @" +
+            throw new IgniteCheckedException("Invalid method signature. Only one method parameter can may annotated with @" +
                 GridifyInput.class.getSimpleName() +
                 "[mtdName=" + mtd.getName() + ", allowedTypes=" + GridifyUtils.getAllowedMethodParameterTypes() +
                 ", annParamIdxs=" + annParamIdxs + ']');
         }
 
         if (allowedParamIdxs.size() > 1 && annParamIdxs.isEmpty()) {
-            throw new GridException("Invalid method signature. Method parameter must be annotated with @" +
+            throw new IgniteCheckedException("Invalid method signature. Method parameter must be annotated with @" +
                 GridifyInput.class.getSimpleName() +
                 "[mtdName=" + mtd.getName() + ", allowedTypes=" + GridifyUtils.getAllowedMethodParameterTypes() +
                 ", allowedParamIdxs=" + allowedParamIdxs + ']');
         }
 
         if (!annParamIdxs.isEmpty() && !allowedParamIdxs.contains(annParamIdxs.get(0))) {
-            throw new GridException("Invalid method signature. Invalid annotated parameter " +
+            throw new IgniteCheckedException("Invalid method signature. Invalid annotated parameter " +
                 "[mtdName=" + mtd.getName() + ", allowedTypes=" + GridifyUtils.getAllowedMethodParameterTypes() +
                 ", allowedParamIdxs=" + allowedParamIdxs + ", annParamIdxs=" + annParamIdxs + ']');
         }
@@ -87,11 +87,11 @@ public class GridifySetToValueAbstractAspect {
      *
      * @param arg Gridify argument.
      * @param ann Annotation
      * @throws GridException If split is not allowed with current parameters.
      */
-    protected void checkIsSplitToJobsAllowed(GridifyRangeArgument arg, GridifySetToValue ann) throws GridException {
+    protected void checkIsSplitToJobsAllowed(GridifyRangeArgument arg, GridifySetToValue ann) throws IgniteCheckedException {
         if (arg.getInputSize() == UNKNOWN_SIZE && ann.threshold() <= 0 && ann.splitSize() <= 0) {
-            throw new GridException("Failed to split input method argument to jobs with unknown input size and " +
+            throw new IgniteCheckedException("Failed to split input method argument to jobs with unknown input size and " +
                 "invalid annotation parameter 'splitSize' [mtdName=" + arg.getMethodName() + ", inputTypeCls=" +
                 arg.getMethodParameterTypes()[arg.getParamIndex()].getName() +
                 ", threshold=" + ann.threshold() + ", splitSize=" + ann.splitSize() + ']');
@@ -111,10 +111,10 @@ public class GridifySetToValueAbstractAspect {
      * @param splitSize Size of elements to send in job argument.
      * @param timeout Execution timeout.
      * @return Result.
      * @throws GridException If execution failed.
      */
     protected Object execute(Method mtd, IgniteCompute compute, Class<?> cls, GridifyRangeArgument arg,
-        GridifyNodeFilter nodeFilter, int threshold, int splitSize, long timeout) throws GridException {
+        GridifyNodeFilter nodeFilter, int threshold, int splitSize, long timeout) throws IgniteCheckedException {
         long now = U.currentTimeMillis();
 
         long end = timeout == 0 ? Long.MAX_VALUE : timeout + now;
@@ -141,7 +141,7 @@ public class GridifySetToValueAbstractAspect {
                     return mtd.invoke(arg.getTarget(), taskArg.getMethodParameters());
                 }
                 catch (IllegalAccessException | InvocationTargetException e) {
-                    throw new GridException("Failed to execute method locally.", e);
+                    throw new IgniteCheckedException("Failed to execute method locally.", e);
                 }
             }
             else {
@@ -159,10 +159,10 @@ public class GridifySetToValueAbstractAspect {
      * @param arg GridifyArgument with all method signature parameters.
      * @param taskRes Result of last task execution.
      * @return New gridify argument or {@code null} if calculation finished.
      * @throws GridException In case of error.
      */
     private GridifyRangeArgument createGridifyArgument(GridifyRangeArgument arg, Collection<?> taskRes)
-        throws GridException {
+        throws IgniteCheckedException {
         // If first run.
         if (taskRes == null)
             return arg;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java
----------------------------------------------------------------------
@@ -30,9 +30,9 @@ public class GridifySetToValueAbstractAspect {
      *
      * @param mtd Grid-enabled method.
-     * @throws GridException If method signature invalid.
+     * @throws IgniteCheckedException If method signature invalid.
      */
@@ -87,11 +87,11 @@ public class GridifySetToValueAbstractAspect {
      * @param arg Gridify argument.
      * @param ann Annotation
-     * @throws GridException If split is not allowed with current parameters.
+     * @throws IgniteCheckedException If split is not allowed with current parameters.
      */
@@ -111,10 +111,10 @@ public class GridifySetToValueAbstractAspect {
      * @param timeout Execution timeout.
      * @return Result.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
     protected Object execute(Method mtd, IgniteCompute compute, Class<?> cls, GridifyRangeArgument arg,
@@ -159,10 +159,10 @@ public class GridifySetToValueAbstractAspect {
      * @param taskRes Result of last task execution.
      * @return New gridify argument or {@code null} if calculation finished.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     private GridifyRangeArgument createGridifyArgument(GridifyRangeArgument arg, Collection<?> taskRes)
diff --git a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java
index 99d308a..3545a27 100644
--- a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java
+++ b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.configuration;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 import java.net.*;
 import java.util.*;
@@ -29,7 +29,7 @@ public interface IgniteAddressResolver {
      *      Note that if there are more than one external network the local address
      *      can be mapped differently to each and therefore may need to return
      *      multiple external addresses.
      * @throws org.gridgain.grid.GridException Thrown if any exception occurs.
      */
-    public Collection<InetSocketAddress> getExternalAddresses(InetSocketAddress addr) throws GridException;
+    public Collection<InetSocketAddress> getExternalAddresses(InetSocketAddress addr) throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/dataload/IgniteDataLoadCacheUpdater.java
----------------------------------------------------------------------
@@ -29,7 +29,7 @@ public interface IgniteAddressResolver {
      *      can be mapped differently to each and therefore may need to return
      *      multiple external addresses.
-     * @throws org.gridgain.grid.GridException Thrown if any exception occurs.
+     * @throws IgniteCheckedException Thrown if any exception occurs.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/dataload/IgniteDataLoadCacheUpdater.java b/modules/core/src/main/java/org/apache/ignite/dataload/IgniteDataLoadCacheUpdater.java
index a9aab26..88483b6 100644
--- a/modules/core/src/main/java/org/apache/ignite/dataload/IgniteDataLoadCacheUpdater.java
+++ b/modules/core/src/main/java/org/apache/ignite/dataload/IgniteDataLoadCacheUpdater.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.dataload;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.cache.*;
 
 import java.io.*;
@@ -29,7 +29,7 @@ public interface IgniteDataLoadCacheUpdater<K, V> extends Serializable {
      *
      * @param cache Cache.
      * @param entries Collection of entries.
      * @throws GridException If failed.
      */
-    public void update(GridCache<K, V> cache, Collection<Map.Entry<K, V>> entries) throws GridException;
+    public void update(GridCache<K, V> cache, Collection<Map.Entry<K, V>> entries) throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java
----------------------------------------------------------------------
@@ -29,7 +29,7 @@ public interface IgniteDataLoadCacheUpdater<K, V> extends Serializable {
      * @param cache Cache.
      * @param entries Collection of entries.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java
index 4cd30ac..cd94d7d 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.fs;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -40,9 +40,9 @@ public interface IgniteFsFileSystem {
      *
      * @param path Path to check for existence in the file system.
      * @return {@code True} if such file exists, otherwise - {@code false}.
      * @throws GridException In case of error.
      */
-    public boolean exists(IgniteFsPath path) throws GridException;
+    public boolean exists(IgniteFsPath path) throws IgniteCheckedException;
 
     /**
      * Updates file information for the specified path. Existent properties, not listed in the passed collection,
@@ -60,9 +60,9 @@ public interface IgniteFsFileSystem {
      * @param path File path to set properties for.
      * @param props Properties to update.
      * @return File information for specified path or {@code null} if such path does not exist.
      * @throws GridException In case of error.
      */
-    @Nullable public IgniteFsFile update(IgniteFsPath path, Map<String, String> props) throws GridException;
+    @Nullable public IgniteFsFile update(IgniteFsPath path, Map<String, String> props) throws IgniteCheckedException;
 
     /**
      * Renames/moves a file.
@@ -80,10 +80,10 @@ public interface IgniteFsFileSystem {
      * @param src Source file path to rename.
      * @param dest Destination file path. If destination path is a directory, then source file will be placed
      *     into destination directory with original name.
      * @throws GridException In case of error.
      * @throws IgniteFsFileNotFoundException If source file doesn't exist.
      */
-    public void rename(IgniteFsPath src, IgniteFsPath dest) throws GridException;
+    public void rename(IgniteFsPath src, IgniteFsPath dest) throws IgniteCheckedException;
 
     /**
      * Deletes file.
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param path File path to delete.
      * @param recursive Delete non-empty directories recursively.
      * @return {@code True} in case of success, {@code false} otherwise.
      * @throws GridException In case of error.
      */
-    boolean delete(IgniteFsPath path, boolean recursive) throws GridException;
+    boolean delete(IgniteFsPath path, boolean recursive) throws IgniteCheckedException;
 
     /**
      * Creates directories under specified path.
      *
      * @param path Path of directories chain to create.
      * @throws GridException In case of error.
      */
-    public void mkdirs(IgniteFsPath path) throws GridException;
+    public void mkdirs(IgniteFsPath path) throws IgniteCheckedException;
 
     /**
      * Creates directories under specified path with the specified properties.
      *
      * @param path Path of directories chain to create.
      * @param props Metadata properties to set on created directories.
      * @throws GridException In case of error.
      */
-    public void mkdirs(IgniteFsPath path, @Nullable Map<String, String> props) throws GridException;
+    public void mkdirs(IgniteFsPath path, @Nullable Map<String, String> props) throws IgniteCheckedException;
 
     /**
      * Lists file paths under the specified path.
      *
      * @param path Path to list files under.
      * @return List of files under the specified path.
      * @throws GridException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
-    public Collection<IgniteFsPath> listPaths(IgniteFsPath path) throws GridException;
+    public Collection<IgniteFsPath> listPaths(IgniteFsPath path) throws IgniteCheckedException;
 
     /**
      * Lists files under the specified path.
      *
      * @param path Path to list files under.
      * @return List of files under the specified path.
      * @throws GridException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
-    public Collection<IgniteFsFile> listFiles(IgniteFsPath path) throws GridException;
+    public Collection<IgniteFsFile> listFiles(IgniteFsPath path) throws IgniteCheckedException;
 
     /**
      * Opens a file for reading.
@@ -138,10 +138,10 @@ public interface IgniteFsFileSystem {
      * @param path File path to read.
      * @param bufSize Read buffer size (bytes) or {@code zero} to use default value.
      * @return File input stream to read data from.
      * @throws GridException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
-    public IgniteFsReader open(IgniteFsPath path, int bufSize) throws GridException;
+    public IgniteFsReader open(IgniteFsPath path, int bufSize) throws IgniteCheckedException;
 
     /**
      * Creates a file and opens it for writing.
@@ -149,9 +149,9 @@ public interface IgniteFsFileSystem {
      * @param path File path to create.
      * @param overwrite Overwrite file if it already exists. Note: you cannot overwrite an existent directory.
      * @return File output stream to write data to.
      * @throws GridException In case of error.
      */
-    public OutputStream create(IgniteFsPath path, boolean overwrite) throws GridException;
+    public OutputStream create(IgniteFsPath path, boolean overwrite) throws IgniteCheckedException;
 
     /**
      * Creates a file and opens it for writing.
@@ -163,10 +163,10 @@ public interface IgniteFsFileSystem {
      * @param blockSize Block size.
      * @param props File properties to set.
      * @return File output stream to write data to.
      * @throws GridException In case of error.
      */
     public OutputStream create(IgniteFsPath path, int bufSize, boolean overwrite, int replication, long blockSize,
-       @Nullable Map<String, String> props) throws GridException;
+       @Nullable Map<String, String> props) throws IgniteCheckedException;
 
     /**
      * Opens an output stream to an existing file for appending data.
@@ -176,28 +176,28 @@ public interface IgniteFsFileSystem {
      * @param create Create file if it doesn't exist yet.
      * @param props File properties to set only in case it file was just created.
      * @return File output stream to append data to.
      * @throws GridException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist and create flag is {@code false}.
      */
     public OutputStream append(IgniteFsPath path, int bufSize, boolean create, @Nullable Map<String, String> props)
-        throws GridException;
+        throws IgniteCheckedException;
 
     /**
      * Gets file information for the specified path.
      *
      * @param path Path to get information for.
      * @return File information for specified path or {@code null} if such path does not exist.
      * @throws GridException In case of error.
      */
-    @Nullable public IgniteFsFile info(IgniteFsPath path) throws GridException;
+    @Nullable public IgniteFsFile info(IgniteFsPath path) throws IgniteCheckedException;
 
     /**
      * Gets used space in bytes.
      *
      * @return Used space in bytes.
      * @throws GridException In case of error.
      */
-    public long usedSpaceSize() throws GridException;
+    public long usedSpaceSize() throws IgniteCheckedException;
 
     /**
      * Gets the implementation specific properties of file system.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java
----------------------------------------------------------------------
@@ -40,9 +40,9 @@ public interface IgniteFsFileSystem {
      * @param path Path to check for existence in the file system.
      * @return {@code True} if such file exists, otherwise - {@code false}.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -60,9 +60,9 @@ public interface IgniteFsFileSystem {
      * @param props Properties to update.
      * @return File information for specified path or {@code null} if such path does not exist.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -80,10 +80,10 @@ public interface IgniteFsFileSystem {
      * @param dest Destination file path. If destination path is a directory, then source file will be placed
      *     into destination directory with original name.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If source file doesn't exist.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param recursive Delete non-empty directories recursively.
      * @return {@code True} in case of success, {@code false} otherwise.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      *
      * @param path Path of directories chain to create.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param path Path of directories chain to create.
      * @param props Metadata properties to set on created directories.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param path Path to list files under.
      * @return List of files under the specified path.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param path Path to list files under.
      * @return List of files under the specified path.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
@@ -138,10 +138,10 @@ public interface IgniteFsFileSystem {
      * @param bufSize Read buffer size (bytes) or {@code zero} to use default value.
      * @return File input stream to read data from.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
@@ -149,9 +149,9 @@ public interface IgniteFsFileSystem {
      * @param overwrite Overwrite file if it already exists. Note: you cannot overwrite an existent directory.
      * @return File output stream to write data to.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -163,10 +163,10 @@ public interface IgniteFsFileSystem {
      * @param props File properties to set.
      * @return File output stream to write data to.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public OutputStream create(IgniteFsPath path, int bufSize, boolean overwrite, int replication, long blockSize,
@@ -176,28 +176,28 @@ public interface IgniteFsFileSystem {
      * @param props File properties to set only in case it file was just created.
      * @return File output stream to append data to.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist and create flag is {@code false}.
      */
@@ -176,28 +176,28 @@ public interface IgniteFsFileSystem {
      * @param path Path to get information for.
      * @return File information for specified path or {@code null} if such path does not exist.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -176,28 +176,28 @@ public interface IgniteFsFileSystem {
      *
      * @return Used space in bytes.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java
index 23449be..079891a 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java
@@ -26,7 +26,7 @@ import java.io.*;
 public abstract class IgniteFsInputStreamJobAdapter extends IgniteFsJobAdapter {
     /** {@inheritDoc} */
     @Override public final Object execute(IgniteFs ggfs, IgniteFsFileRange range, IgniteFsInputStream in)
-        throws GridException, IOException {
+        throws IgniteCheckedException, IOException {
         in.seek(range.start());
 
         return execute(ggfs, new IgniteFsRangeInputStream(in, range));
@@ -38,8 +38,8 @@ public abstract class IgniteFsInputStreamJobAdapter extends IgniteFsJobAdapter {
      * @param ggfs GGFS instance.
      * @param in Input stream.
      * @return Execution result.
      * @throws GridException If execution failed.
      * @throws IOException If IO exception encountered while working with stream.
      */
-    public abstract Object execute(IgniteFs ggfs, IgniteFsRangeInputStream in) throws GridException, IOException;
+    public abstract Object execute(IgniteFs ggfs, IgniteFsRangeInputStream in) throws IgniteCheckedException, IOException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
----------------------------------------------------------------------
@@ -38,8 +38,8 @@ public abstract class IgniteFsInputStreamJobAdapter extends IgniteFsJobAdapter {
      * @param in Input stream.
      * @return Execution result.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      * @throws IOException If IO exception encountered while working with stream.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
index b4921eb..8fdc30c 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
@@ -42,10 +42,10 @@ public interface IgniteFsJob {
      * @param in Input stream for split file. This input stream is not aligned to range and points to file start
      *     by default.
      * @return Execution result.
      * @throws GridException If execution failed.
      * @throws IOException If file system operation resulted in IO exception.
      */
-    public Object execute(IgniteFs ggfs, IgniteFsFileRange range, IgniteFsInputStream in) throws GridException,
+    public Object execute(IgniteFs ggfs, IgniteFsFileRange range, IgniteFsInputStream in) throws IgniteCheckedException,
         IOException;
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java
----------------------------------------------------------------------
@@ -42,10 +42,10 @@ public interface IgniteFsJob {
      *     by default.
      * @return Execution result.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      * @throws IOException If file system operation resulted in IO exception.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java
index 3e96dcf..0f4fab2 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java
@@ -41,9 +41,9 @@ public interface IgniteFsRecordResolver extends Serializable {
      * @param stream Input stream for split file.
      * @param suggestedRecord Suggested file system record.
      * @return New adjusted record. If this method returns {@code null}, original record is ignored.
      * @throws GridException If resolve failed.
      * @throws IOException If resolve failed.
      */
     @Nullable public IgniteFsFileRange resolveRecords(IgniteFs ggfs, IgniteFsInputStream stream,
-        IgniteFsFileRange suggestedRecord) throws GridException, IOException;
+        IgniteFsFileRange suggestedRecord) throws IgniteCheckedException, IOException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java
----------------------------------------------------------------------
@@ -41,9 +41,9 @@ public interface IgniteFsRecordResolver extends Serializable {
      * @param suggestedRecord Suggested file system record.
      * @return New adjusted record. If this method returns {@code null}, original record is ignored.
-     * @throws GridException If resolve failed.
+     * @throws IgniteCheckedException If resolve failed.
      * @throws IOException If resolve failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java
index 32580ab..e7323d7 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java
@@ -44,14 +44,14 @@ import java.util.*;
  * <pre name="code" class="java">
  * public class WordCountTask extends GridGgfsTask&lt;String, Integer&gt; {
  *     &#64;Override
- *     public GridGgfsJob createJob(GridGgfsPath path, GridGgfsFileRange range, GridGgfsTaskArgs&lt;T&gt; args) throws GridException {
+ *     public GridGgfsJob createJob(GridGgfsPath path, GridGgfsFileRange range, GridGgfsTaskArgs&lt;T&gt; args) throws IgniteCheckedException {
  *         // New job will be created for each range within each file.
  *         // We pass user-provided argument (which is essentially a word to look for) to that job.
  *         return new WordCountJob(args.userArgument());
  *     }
  *
  *     // Aggregate results into one compound result.
- *     public Integer reduce(List&lt;GridComputeJobResult&gt; results) throws GridException {
+ *     public Integer reduce(List&lt;GridComputeJobResult&gt; results) throws IgniteCheckedException {
  *         Integer total = 0;
  *
  *         for (GridComputeJobResult res : results) {
@@ -77,7 +77,7 @@ public abstract class IgniteFsTask<T, R> extends ComputeTaskAdapter<IgniteFsTask
 
     /** {@inheritDoc} */
     @Nullable @Override public final Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid,
-        @Nullable IgniteFsTaskArgs<T> args) throws GridException {
+        @Nullable IgniteFsTaskArgs<T> args) throws IgniteCheckedException {
         assert ignite != null;
         assert args != null;
 
@@ -95,7 +95,7 @@ public abstract class IgniteFsTask<T, R> extends ComputeTaskAdapter<IgniteFsTask
                 if (args.skipNonExistentFiles())
                     continue;
                 else
-                    throw new GridException("Failed to process GGFS file because it doesn't exist: " + path);
+                    throw new IgniteCheckedException("Failed to process GGFS file because it doesn't exist: " + path);
             }
 
             Collection<IgniteFsBlockLocation> aff = ggfs.affinity(path, 0, file.length(), args.maxRangeLength());
@@ -113,7 +113,7 @@ public abstract class IgniteFsTask<T, R> extends ComputeTaskAdapter<IgniteFsTask
                 }
 
                 if (node == null)
-                    throw new GridException("Failed to find any of block affinity nodes in subgrid [loc=" + loc +
+                    throw new IgniteCheckedException("Failed to find any of block affinity nodes in subgrid [loc=" + loc +
                         ", subgrid=" + subgrid + ']');
 
                 IgniteFsJob job = createJob(path, new IgniteFsFileRange(file.path(), loc.start(), loc.length()), args);
@@ -143,10 +143,10 @@ public abstract class IgniteFsTask<T, R> extends ComputeTaskAdapter<IgniteFsTask
      *      realigned to record boundaries on destination node.
      * @param args Task argument.
      * @return GGFS job. If {@code null} is returned, the passed in file range will be skipped.
      * @throws GridException If job creation failed.
      */
     @Nullable public abstract IgniteFsJob createJob(IgniteFsPath path, IgniteFsFileRange range,
-        IgniteFsTaskArgs<T> args) throws GridException;
+        IgniteFsTaskArgs<T> args) throws IgniteCheckedException;
 
     /**
      * Maps list by node ID.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java
----------------------------------------------------------------------
@@ -143,10 +143,10 @@ public abstract class IgniteFsTask<T, R> extends ComputeTaskAdapter<IgniteFsTask
      * @param args Task argument.
      * @return GGFS job. If {@code null} is returned, the passed in file range will be skipped.
-     * @throws GridException If job creation failed.
+     * @throws IgniteCheckedException If job creation failed.
      */
     @Nullable public abstract IgniteFsJob createJob(IgniteFsPath path, IgniteFsFileRange range,
diff --git a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
index cc4cbbb..fe55b87 100644
--- a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
+++ b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.lang;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 /**
  * Adapter for {@link IgniteAsyncSupport}.
@@ -62,9 +62,9 @@ public class IgniteAsyncSupportAdapter implements IgniteAsyncSupport {
      * @param fut Future.
      * @return If async mode is enabled saves future and returns {@code null},
      *         otherwise waits for future and returns result.
      * @throws GridException If asynchronous mode is disabled and future failed.
      */
-    public <R> R saveOrGet(IgniteFuture<R> fut) throws GridException {
+    public <R> R saveOrGet(IgniteFuture<R> fut) throws IgniteCheckedException {
         if (curFut != null) {
             curFut.set(fut);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
----------------------------------------------------------------------
@@ -62,9 +62,9 @@ public class IgniteAsyncSupportAdapter implements IgniteAsyncSupport {
      * @return If async mode is enabled saves future and returns {@code null},
      *         otherwise waits for future and returns result.
-     * @throws GridException If asynchronous mode is disabled and future failed.
+     * @throws IgniteCheckedException If asynchronous mode is disabled and future failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
index c597d92..f478377 100644
--- a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
@@ -9,6 +9,7 @@
 
 package org.apache.ignite.lang;
 
+import org.apache.ignite.*;
 import org.gridgain.grid.*;
 import org.jetbrains.annotations.*;
 
@@ -26,11 +27,11 @@ public interface IgniteFuture<R> {
      * returns computation result.
      *
      * @return Computation result.
      * @throws org.gridgain.grid.GridInterruptedException Subclass of {@link org.gridgain.grid.GridException} thrown if the wait was interrupted.
      * @throws IgniteFutureCancelledException Subclass of {@link org.gridgain.grid.GridException} throws if computation was cancelled.
      * @throws org.gridgain.grid.GridException If computation failed.
      */
-    public R get() throws GridException;
+    public R get() throws IgniteCheckedException;
 
     /**
      * Synchronously waits for completion of the computation for
@@ -39,12 +40,12 @@ public interface IgniteFuture<R> {
      *
      * @param timeout The maximum time to wait in milliseconds.
      * @return Computation result.
      * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
      * @throws IgniteFutureTimeoutException Subclass of {@link GridException} thrown if the wait was timed out.
      * @throws IgniteFutureCancelledException Subclass of {@link GridException} throws if computation was cancelled.
      * @throws GridException If computation failed.
      */
-    public R get(long timeout) throws GridException;
+    public R get(long timeout) throws IgniteCheckedException;
 
     /**
      * Synchronously waits for completion of the computation for
@@ -53,20 +54,20 @@ public interface IgniteFuture<R> {
      * @param timeout The maximum time to wait.
      * @param unit The time unit of the {@code timeout} argument.
      * @return Computation result.
      * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
      * @throws IgniteFutureTimeoutException Subclass of {@link GridException} thrown if the wait was timed out.
      * @throws IgniteFutureCancelledException Subclass of {@link GridException} throws if computation was cancelled.
      * @throws GridException If computation failed.
      */
-    public R get(long timeout, TimeUnit unit) throws GridException;
+    public R get(long timeout, TimeUnit unit) throws IgniteCheckedException;
 
     /**
      * Cancels this future.
      *
      * @return {@code True} if future was canceled (i.e. was not finished prior to this call).
      * @throws GridException If cancellation failed.
      */
-    public boolean cancel() throws GridException;
+    public boolean cancel() throws IgniteCheckedException;
 
     /**
      * Checks if computation is done.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java
----------------------------------------------------------------------
@@ -26,11 +27,11 @@ public interface IgniteFuture<R> {
      *
      * @return Computation result.
-     * @throws org.gridgain.grid.GridInterruptedException Subclass of {@link org.gridgain.grid.GridException} thrown if the wait was interrupted.
-     * @throws IgniteFutureCancelledException Subclass of {@link org.gridgain.grid.GridException} throws if computation was cancelled.
-     * @throws org.gridgain.grid.GridException If computation failed.
+     * @throws org.gridgain.grid.GridInterruptedException Subclass of {@link IgniteCheckedException} thrown if the wait was interrupted.
+     * @throws IgniteFutureCancelledException Subclass of {@link IgniteCheckedException} throws if computation was cancelled.
+     * @throws IgniteCheckedException If computation failed.
      */
@@ -39,12 +40,12 @@ public interface IgniteFuture<R> {
      * @param timeout The maximum time to wait in milliseconds.
      * @return Computation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
-     * @throws IgniteFutureTimeoutException Subclass of {@link GridException} thrown if the wait was timed out.
-     * @throws IgniteFutureCancelledException Subclass of {@link GridException} throws if computation was cancelled.
-     * @throws GridException If computation failed.
+     * @throws GridInterruptedException Subclass of {@link IgniteCheckedException} thrown if the wait was interrupted.
+     * @throws IgniteFutureTimeoutException Subclass of {@link IgniteCheckedException} thrown if the wait was timed out.
+     * @throws IgniteFutureCancelledException Subclass of {@link IgniteCheckedException} throws if computation was cancelled.
+     * @throws IgniteCheckedException If computation failed.
      */
@@ -53,20 +54,20 @@ public interface IgniteFuture<R> {
      * @param unit The time unit of the {@code timeout} argument.
      * @return Computation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} thrown if the wait was interrupted.
-     * @throws IgniteFutureTimeoutException Subclass of {@link GridException} thrown if the wait was timed out.
-     * @throws IgniteFutureCancelledException Subclass of {@link GridException} throws if computation was cancelled.
-     * @throws GridException If computation failed.
+     * @throws GridInterruptedException Subclass of {@link IgniteCheckedException} thrown if the wait was interrupted.
+     * @throws IgniteFutureTimeoutException Subclass of {@link IgniteCheckedException} thrown if the wait was timed out.
+     * @throws IgniteFutureCancelledException Subclass of {@link IgniteCheckedException} throws if computation was cancelled.
+     * @throws IgniteCheckedException If computation failed.
      */
@@ -53,20 +54,20 @@ public interface IgniteFuture<R> {
      *
      * @return {@code True} if future was canceled (i.e. was not finished prior to this call).
-     * @throws GridException If cancellation failed.
+     * @throws IgniteCheckedException If cancellation failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java
index b9bb656..beb617d 100644
--- a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java
+++ b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.lifecycle;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 /**
  * All components provided in GridGain configuration can implement this interface.
@@ -20,14 +20,14 @@ public interface LifecycleAware {
     /**
      * Starts grid component, called on grid start.
      *
-     * @throws org.gridgain.grid.GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    public void start() throws GridException;
+    public void start() throws IgniteCheckedException;
 
     /**
      * Stops grid component, called on grid shutdown.
      *
      * @throws GridException If failed.
      */
-    public void stop() throws GridException;
+    public void stop() throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
----------------------------------------------------------------------
@@ -20,14 +20,14 @@ public interface LifecycleAware {
      * Stops grid component, called on grid shutdown.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
index 3455fb6..ccca6ba 100644
--- a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
+++ b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.lifecycle;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 /**
  * A bean that reacts to grid lifecycle events defined in {@link LifecycleEventType}.
@@ -98,7 +98,7 @@ public interface LifecycleBean {
      * This method is called when lifecycle event occurs.
      *
      * @param evt Lifecycle event.
      * @throws org.gridgain.grid.GridException Thrown in case of any errors.
      */
-    public void onLifecycleEvent(LifecycleEventType evt) throws GridException;
+    public void onLifecycleEvent(LifecycleEventType evt) throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/logger/java/IgniteJavaLogger.java
----------------------------------------------------------------------
@@ -98,7 +98,7 @@ public interface LifecycleBean {
      *
      * @param evt Lifecycle event.
-     * @throws org.gridgain.grid.GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java
index 033f54b..5fd97af 100644
--- a/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java
+++ b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.marshaller;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -90,18 +90,18 @@ public interface IgniteMarshaller {
      *
      * @param obj Object to marshal.
      * @param out Output stream to marshal into.
      * @throws GridException If marshalling failed.
      */
-    public void marshal(@Nullable Object obj, OutputStream out) throws GridException;
+    public void marshal(@Nullable Object obj, OutputStream out) throws IgniteCheckedException;
 
     /**
      * Marshals object to byte array.
      *
      * @param obj Object to marshal.
      * @return Byte array.
      * @throws GridException If marshalling failed.
      */
-    public byte[] marshal(@Nullable Object obj) throws GridException;
+    public byte[] marshal(@Nullable Object obj) throws IgniteCheckedException;
 
     /**
      * Unmarshals object from the output stream using given class loader.
@@ -111,9 +111,9 @@ public interface IgniteMarshaller {
      * @param in Input stream.
      * @param clsLdr Class loader to use.
      * @return Unmarshalled object.
      * @throws GridException If unmarshalling failed.
      */
-    public <T> T unmarshal(InputStream in, @Nullable ClassLoader clsLdr) throws GridException;
+    public <T> T unmarshal(InputStream in, @Nullable ClassLoader clsLdr) throws IgniteCheckedException;
 
     /**
      * Unmarshals object from byte array using given class loader.
@@ -122,7 +122,7 @@ public interface IgniteMarshaller {
      * @param arr Byte array.
      * @param clsLdr Class loader to use.
      * @return Unmarshalled object.
      * @throws GridException If unmarshalling failed.
      */
-    public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) throws GridException;
+    public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java
----------------------------------------------------------------------
@@ -90,18 +90,18 @@ public interface IgniteMarshaller {
      * @param obj Object to marshal.
      * @param out Output stream to marshal into.
-     * @throws GridException If marshalling failed.
+     * @throws IgniteCheckedException If marshalling failed.
      */
@@ -90,18 +90,18 @@ public interface IgniteMarshaller {
      * @param obj Object to marshal.
      * @return Byte array.
-     * @throws GridException If marshalling failed.
+     * @throws IgniteCheckedException If marshalling failed.
      */
@@ -111,9 +111,9 @@ public interface IgniteMarshaller {
      * @param clsLdr Class loader to use.
      * @return Unmarshalled object.
-     * @throws GridException If unmarshalling failed.
+     * @throws IgniteCheckedException If unmarshalling failed.
      */
@@ -122,7 +122,7 @@ public interface IgniteMarshaller {
      * @param clsLdr Class loader to use.
      * @return Unmarshalled object.
-     * @throws GridException If unmarshalling failed.
+     * @throws IgniteCheckedException If unmarshalling failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
index 02632d9..d42954a 100644
--- a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
+++ b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
@@ -9,8 +9,8 @@
 
 package org.apache.ignite.marshaller.optimized;
 
+import org.apache.ignite.*;
 import org.apache.ignite.marshaller.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
@@ -101,11 +101,11 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
     /**
      * Initializes marshaller not to enforce {@link Serializable} interface.
      *
      * @throws GridRuntimeException If this marshaller is not supported on the current JVM.
      */
     public IgniteOptimizedMarshaller() {
         if (!available())
-            throw new GridRuntimeException("Using GridOptimizedMarshaller on unsupported JVM version (some of " +
+            throw new IgniteException("Using GridOptimizedMarshaller on unsupported JVM version (some of " +
                 "JVM-private APIs required for the marshaller to work are missing).");
     }
 
@@ -117,7 +117,7 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
      * @param requireSer Flag to enforce {@link Serializable} interface or not. If {@code true},
      *      then objects will be required to implement {@link Serializable} in order to be
      *      marshalled, if {@code false}, then such requirement will be relaxed.
      * @throws GridRuntimeException If this marshaller is not supported on the current JVM.
      */
     public IgniteOptimizedMarshaller(boolean requireSer) {
         this();
@@ -136,11 +136,11 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
      * @param clsNames User preregistered class names.
      * @param clsNamesPath Path to a file with user preregistered class names.
      * @param poolSize Object streams pool size.
      * @throws GridException If an I/O error occurs while writing stream header.
      * @throws GridRuntimeException If this marshaller is not supported on the current JVM.
      */
     public IgniteOptimizedMarshaller(boolean requireSer, @Nullable List<String> clsNames,
-                                     @Nullable String clsNamesPath, int poolSize) throws GridException {
+                                     @Nullable String clsNamesPath, int poolSize) throws IgniteCheckedException {
         this(requireSer);
 
         setClassNames(clsNames);
@@ -192,16 +192,16 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
      * <b>NOTE</b>: this class list must be identical on all nodes and in the same order.
      *
      * @param path Path to a file with user preregistered class names.
      * @throws GridException If an error occurs while writing stream header.
      */
-    public void setClassNamesPath(@Nullable String path) throws GridException {
+    public void setClassNamesPath(@Nullable String path) throws IgniteCheckedException {
         if (path == null)
             return;
 
         URL url = GridUtils.resolveGridGainUrl(path, false);
 
         if (url == null)
-            throw new GridException("Failed to find resource for name: " + path);
+            throw new IgniteCheckedException("Failed to find resource for name: " + path);
 
         List<String> clsNames;
 
@@ -216,7 +216,7 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
             }
         }
         catch (IOException e) {
-            throw new GridException("Failed to read class names from path: " + path, e);
+            throw new IgniteCheckedException("Failed to read class names from path: " + path, e);
         }
 
         setClassNames(clsNames);
@@ -260,7 +260,7 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public void marshal(@Nullable Object obj, OutputStream out) throws GridException {
+    @Override public void marshal(@Nullable Object obj, OutputStream out) throws IgniteCheckedException {
         assert out != null;
 
         IgniteOptimizedObjectOutputStream objOut = null;
@@ -275,7 +275,7 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
             objOut.writeObject(obj);
         }
         catch (IOException e) {
-            throw new GridException("Failed to serialize object: " + obj, e);
+            throw new IgniteCheckedException("Failed to serialize object: " + obj, e);
         }
         finally {
             IgniteOptimizedObjectStreamRegistry.closeOut(objOut);
@@ -283,7 +283,7 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public byte[] marshal(@Nullable Object obj) throws GridException {
+    @Override public byte[] marshal(@Nullable Object obj) throws IgniteCheckedException {
         IgniteOptimizedObjectOutputStream objOut = null;
 
         try {
@@ -296,7 +296,7 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
             return objOut.out().array();
         }
         catch (IOException e) {
-            throw new GridException("Failed to serialize object: " + obj, e);
+            throw new IgniteCheckedException("Failed to serialize object: " + obj, e);
         }
         finally {
             IgniteOptimizedObjectStreamRegistry.closeOut(objOut);
@@ -304,7 +304,7 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public <T> T unmarshal(InputStream in, @Nullable ClassLoader clsLdr) throws GridException {
+    @Override public <T> T unmarshal(InputStream in, @Nullable ClassLoader clsLdr) throws IgniteCheckedException {
         assert in != null;
 
         IgniteOptimizedObjectInputStream objIn = null;
@@ -319,10 +319,10 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
             return (T)objIn.readObject();
         }
         catch (IOException e) {
-            throw new GridException("Failed to deserialize object with given class loader: " + clsLdr, e);
+            throw new IgniteCheckedException("Failed to deserialize object with given class loader: " + clsLdr, e);
         }
         catch (ClassNotFoundException e) {
-            throw new GridException("Failed to find class with given class loader for unmarshalling " +
+            throw new IgniteCheckedException("Failed to find class with given class loader for unmarshalling " +
                 "(make sure same versions of all classes are available on all nodes or enable peer-class-loading): " +
                 clsLdr, e);
         }
@@ -332,7 +332,7 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) throws GridException {
+    @Override public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) throws IgniteCheckedException {
         assert arr != null;
 
         IgniteOptimizedObjectInputStream objIn = null;
@@ -347,10 +347,10 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
             return (T)objIn.readObject();
         }
         catch (IOException e) {
-            throw new GridException("Failed to deserialize object with given class loader: " + clsLdr, e);
+            throw new IgniteCheckedException("Failed to deserialize object with given class loader: " + clsLdr, e);
         }
         catch (ClassNotFoundException e) {
-            throw new GridException("Failed to find class with given class loader for unmarshalling " +
+            throw new IgniteCheckedException("Failed to find class with given class loader for unmarshalling " +
                 "(make sure same version of all classes are available on all nodes or enable peer-class-loading): " +
                 clsLdr, e);
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedObjectStreamRegistry.java
----------------------------------------------------------------------
@@ -101,11 +101,11 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
      * Initializes marshaller not to enforce {@link Serializable} interface.
      *
-     * @throws GridRuntimeException If this marshaller is not supported on the current JVM.
+     * @throws IgniteException If this marshaller is not supported on the current JVM.
      */
     public IgniteOptimizedMarshaller() {
@@ -117,7 +117,7 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
      *      then objects will be required to implement {@link Serializable} in order to be
      *      marshalled, if {@code false}, then such requirement will be relaxed.
-     * @throws GridRuntimeException If this marshaller is not supported on the current JVM.
+     * @throws IgniteException If this marshaller is not supported on the current JVM.
      */
     public IgniteOptimizedMarshaller(boolean requireSer) {
@@ -136,11 +136,11 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
      * @param clsNamesPath Path to a file with user preregistered class names.
      * @param poolSize Object streams pool size.
-     * @throws GridException If an I/O error occurs while writing stream header.
-     * @throws GridRuntimeException If this marshaller is not supported on the current JVM.
+     * @throws IgniteCheckedException If an I/O error occurs while writing stream header.
+     * @throws IgniteException If this marshaller is not supported on the current JVM.
      */
     public IgniteOptimizedMarshaller(boolean requireSer, @Nullable List<String> clsNames,
@@ -192,16 +192,16 @@ public class IgniteOptimizedMarshaller extends IgniteAbstractMarshaller {
      *
      * @param path Path to a file with user preregistered class names.
-     * @throws GridException If an error occurs while writing stream header.
+     * @throws IgniteCheckedException If an error occurs while writing stream header.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java b/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java
index d9a5913..1235c4b 100644
--- a/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java
+++ b/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java
@@ -123,9 +123,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      *
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
      * @throws GridException Thrown in case of any errors.
      */
-    protected final void stop(@Nullable Object respMsg) throws GridException {
+    protected final void stop(@Nullable Object respMsg) throws IgniteCheckedException {
         keepGoing = false;
 
         send(nodeId, respMsg);
@@ -154,9 +154,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      *
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
      * @throws GridException Thrown in case of any errors.
      */
-    protected final void respond(@Nullable Object respMsg) throws GridException {
+    protected final void respond(@Nullable Object respMsg) throws IgniteCheckedException {
         checkReversing();
 
         keepGoing = true;
@@ -174,9 +174,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      * @param id ID of the node to send the message to, if any.
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
      * @throws GridException Thrown in case of any errors.
      */
-    protected final void respond(UUID id, @Nullable Object respMsg) throws GridException {
+    protected final void respond(UUID id, @Nullable Object respMsg) throws IgniteCheckedException {
         checkReversing();
 
         keepGoing = true;
@@ -198,9 +198,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      *
      * @param nodeId ID of the node to send message to.
      * @param respMsg Message to send.
      * @throws GridException Thrown in case of any errors.
      */
-    private void send(UUID nodeId, @Nullable Object respMsg) throws GridException {
+    private void send(UUID nodeId, @Nullable Object respMsg) throws IgniteCheckedException {
         assert nodeId != null;
 
         if (respMsg != null) {
@@ -209,7 +209,7 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
             if (node != null)
                 ignite.message(ignite.cluster().forNode(node)).send(null, respMsg); // Can still fail.
             else
-                throw new GridException("Failed to send message since destination node has " +
+                throw new IgniteCheckedException("Failed to send message since destination node has " +
                     "left topology (ignoring) [nodeId=" +nodeId + ", respMsg=" + respMsg + ']');
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java
----------------------------------------------------------------------
@@ -123,9 +123,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -154,9 +154,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -174,9 +174,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -198,9 +198,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      * @param nodeId ID of the node to send message to.
      * @param respMsg Message to send.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java b/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java
index 7dd08b9..33280dc 100644
--- a/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java
+++ b/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java
@@ -9,8 +9,8 @@
 
 package org.apache.ignite.plugin;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
-import org.gridgain.grid.*;
 import org.jetbrains.annotations.*;
 
 import java.util.*;
@@ -57,26 +57,26 @@ public interface PluginProvider<C extends PluginConfiguration> {
      *
      * @param ctx Plugin context.
      * @param attrs Attributes.
      * @throws GridException Throws in case of any errors.
      */
-    public void start(PluginContext ctx, Map<String, Object> attrs) throws GridException;
+    public void start(PluginContext ctx, Map<String, Object> attrs) throws IgniteCheckedException;
 
     /**
      * Stops grid component.
      *
      * @param cancel If {@code true}, then all ongoing tasks or jobs for relevant
      *      components need to be cancelled.
      * @throws GridException Thrown in case of any errors.
      */
-    public void stop(boolean cancel) throws GridException;
+    public void stop(boolean cancel) throws IgniteCheckedException;
 
     /**
      * Callback that notifies that Ignite has successfully started,
      * including all internal components.
      *
      * @throws GridException Thrown in case of any errors.
      */
-    public void onIgniteStart() throws GridException;
+    public void onIgniteStart() throws IgniteCheckedException;
 
     /**
      * Callback to notify that Ignite is about to stop.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java
----------------------------------------------------------------------
@@ -57,26 +57,26 @@ public interface PluginProvider<C extends PluginConfiguration> {
      * @param ctx Plugin context.
      * @param attrs Attributes.
-     * @throws GridException Throws in case of any errors.
+     * @throws IgniteCheckedException Throws in case of any errors.
      */
@@ -57,26 +57,26 @@ public interface PluginProvider<C extends PluginConfiguration> {
      * @param cancel If {@code true}, then all ongoing tasks or jobs for relevant
      *      components need to be cancelled.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -57,26 +57,26 @@ public interface PluginProvider<C extends PluginConfiguration> {
      * including all internal components.
      *
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java
index 2cfb328..b5d8d4e 100644
--- a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java
+++ b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.plugin.security;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 /**
  * Security credentials provider for specifying security credentials.
@@ -35,7 +35,7 @@ public interface GridSecurityCredentialsProvider {
      * Gets security credentials.
      *
      * @return Security credentials.
      * @throws GridException If failed.
      */
-    public GridSecurityCredentials credentials() throws GridException;
+    public GridSecurityCredentials credentials() throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityException.java
----------------------------------------------------------------------
@@ -35,7 +35,7 @@ public interface GridSecurityCredentialsProvider {
      *
      * @return Security credentials.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java b/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java
index 6b8418b..785fde2 100644
--- a/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java
+++ b/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.plugin.segmentation;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 import java.io.*;
 
@@ -50,7 +50,7 @@ public interface GridSegmentationResolver extends Serializable {
      * in configuration.
      *
      * @return {@code True} if segment is correct, {@code false} otherwise.
      * @throws GridException If an error occurred.
      */
-    public abstract boolean isValidSegment() throws GridException;
+    public abstract boolean isValidSegment() throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/portables/PortableException.java
----------------------------------------------------------------------
@@ -50,7 +50,7 @@ public interface GridSegmentationResolver extends Serializable {
      *
      * @return {@code True} if segment is correct, {@code false} otherwise.
-     * @throws GridException If an error occurred.
+     * @throws IgniteCheckedException If an error occurred.
      */